@@ -29,10 +29,6 @@
 
 int main(int argc, char **argv)
 {
-    //Fix QtWebEngine + wayland
-#if defined(Q_OS_UNIX) && QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
-    qputenv("QT_QPA_PLATFORM", "xcb");
-#endif
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
